@@ -1,7 +1,8 @@
 use alloc::boxed::Box;
 
-use crate::proc_macro::TokenStream;
-use crate::syn::{Data, DeriveInput, Fields, Meta, Path};
+use proc_macro::TokenStream;
+use quote::quote;
+use syn::{Data, DeriveInput, Fields, Meta, Path};
 
 use crate::{panic, TypeEnum, Validator};
 
@@ -217,6 +218,13 @@ pub fn boolean_handler(ast: DeriveInput, meta: Meta) -> TokenStream {
                     }
                 };
 
+                let v_parse_bool = quote! {
+                    #[inline]
+                    fn v_parse_bool(b: bool) -> Result<bool, #error_path> {
+                        Ok(b)
+                    }
+                };
+
                 let parse_impl = quote! {
                     impl #name {
                         #v_parse_str
@@ -226,6 +234,8 @@ pub fn boolean_handler(ast: DeriveInput, meta: Meta) -> TokenStream {
                         #v_parse_i128
 
                         #v_parse_u128
+
+                        #v_parse_bool
                     }
                 };
 
@@ -310,6 +320,25 @@ pub fn boolean_handler(ast: DeriveInput, meta: Meta) -> TokenStream {
                     }
                 };
 
+                let validate_boolean_impl = quote! {
+                    impl ValidateBoolean for #name {
+                        type Error = #error_path;
+                        type Output = Self;
+
+                        #[inline]
+                        fn parse_bool(b: bool) -> Result<Self::Output, Self::Error> {
+                            Ok(#name(Self::v_parse_bool(b)?))
+                        }
+
+                        #[inline]
+                        fn validate_bool(b: bool) -> Result<(), Self::Error> {
+                            Self::v_parse_bool(b)?;
+
+                            Ok(())
+                        }
+                    }
+                };
+
                 let serde_impl = if cfg!(feature = "serde") {
                     let expect = "a boolean, a boolean string like \"true\", \"false\", \"0\", \"1\", \"on\", \"off\", \"yes\", \"no\", or a number `0` or `1`";
 
@@ -441,6 +470,8 @@ pub fn boolean_handler(ast: DeriveInput, meta: Meta) -> TokenStream {
 
                     #validate_unsigned_integer_impl
 
+                    #validate_boolean_impl
+
                     #serde_impl
 
                     #rocket_impl
