@@ -5,9 +5,9 @@ use core::fmt::Write;
 use alloc::boxed::Box;
 use alloc::string::{String, ToString};
 
-use crate::proc_macro::TokenStream;
-use crate::quote::ToTokens;
-use crate::syn::{Data, DeriveInput, Fields, Meta, NestedMeta, Path};
+use proc_macro::TokenStream;
+use quote::{quote, ToTokens};
+use syn::{Data, DeriveInput, Fields, Meta, NestedMeta, Path};
 
 use crate::{panic, SynOption, TypeEnum, Validator, ValidatorOption, ValidatorRangeOption};
 
