@@ -1,7 +1,8 @@
 use alloc::boxed::Box;
 
-use crate::proc_macro::TokenStream;
-use crate::syn::{Data, DeriveInput, Fields, Meta, Path};
+use proc_macro::TokenStream;
+use quote::quote;
+use syn::{Data, DeriveInput, Fields, Meta, Path};
 
 use crate::{panic, TypeEnum, Validator};
 
