@@ -3,9 +3,9 @@ use core::fmt::Write;
 use alloc::boxed::Box;
 use alloc::string::{String, ToString};
 
-use crate::proc_macro::TokenStream;
-use crate::quote::ToTokens;
-use crate::syn::{Data, DeriveInput, Fields, Lit, Meta, NestedMeta, Path};
+use proc_macro::TokenStream;
+use quote::{quote, ToTokens};
+use syn::{Data, DeriveInput, Fields, Lit, Meta, NestedMeta, Path};
 
 use crate::{panic, TypeEnum, Validator};
 
